==> activity-center-api-3.4.60-sources.jar: cn/com/duiba/activity/center/api/dto/label/ConsumerLabelStrategyDto.java <==
package cn.com.duiba.activity.center.api.dto.label;

import java.io.Serializable;
import java.util.Date;

/**
* 用户标签策略表
*/
public class ConsumerLabelStrategyDto implements Serializable {

    /**
    * 
    */
    private Long id;

    /**
    * 所属app_id
    */
    private Long appId;

    /**
    * 策略生效对象
    */
    private String strategyName;

    /**
    * 运营策略类型
    */
    private String strategyType;

    /**
    * 用户标签id,多选以[,]隔开
    */
    private String consumerLabelIds;

    /**
    * 策略内容
    */
    private String strategyContent;

    /**
    * 策略状态：1：启用，0：关闭
    */
    private String strategyStatus;
    /**
    * 生效类型：1：商品，2：任务组件
    */
    private Integer strategyObj;

    /**
    * 创建者id
    */
    private String createId;

    /**
     * 弹窗配置-青海中行定制
     */
    private String popConfig;

    /**
    * 修改者id
    */
    private String modifiedId;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    public Integer getStrategyObj() {
        return strategyObj;
    }

    public void setStrategyObj(Integer strategyObj) {
        this.strategyObj = strategyObj;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setStrategyName(String strategyName) {
        this.strategyName = strategyName;
    }

    public String getStrategyName() {
        return strategyName;
    }

    public void setStrategyType(String strategyType) {
        this.strategyType = strategyType;
    }

    public String getStrategyType() {
        return strategyType;
    }

    public void setConsumerLabelIds(String consumerLabelIds) {
        this.consumerLabelIds = consumerLabelIds;
    }

    public String getConsumerLabelIds() {
        return consumerLabelIds;
    }

    public void setStrategyContent(String strategyContent) {
        this.strategyContent = strategyContent;
    }

    public String getStrategyContent() {
        return strategyContent;
    }

    public void setStrategyStatus(String strategyStatus) {
        this.strategyStatus = strategyStatus;
    }

    public String getStrategyStatus() {
        return strategyStatus;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateId() {
        return createId;
    }

    public void setModifiedId(String modifiedId) {
        this.modifiedId = modifiedId;
    }

    public String getModifiedId() {
        return modifiedId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getPopConfig() {
        return popConfig;
    }

    public void setPopConfig(String popConfig) {
        this.popConfig = popConfig;
    }
}

==> activity-center-api-3.4.64-sources.jar: cn/com/duiba/activity/center/api/dto/label/ConsumerLabelStrategyDto.java <==
package cn.com.duiba.activity.center.api.dto.label;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
* 用户标签策略表
*/
public class ConsumerLabelStrategyDto implements Serializable {

    /**
    * 
    */
    private Long id;

    /**
    * 所属app_id
    */
    private Long appId;

    /**
    * 策略名称
    */
    private String strategyName;

    /**
    * 运营策略类型
    */
    private String strategyType;

    /**
    * 用户标签id,多选以[,]隔开
    */
    private String consumerLabelIds;

    /**
    * 策略内容
    */
    private String strategyContent;

    /**
    * 策略状态：1：启用，0：关闭
    */
    private String strategyStatus;
    /**
    * 生效类型：1：商品，2：任务组件
    */
    private Integer strategyObj;

    /**
    * 创建者id
    */
    private String createId;

    /**
     * 弹窗配置-青海中行定制
     */
    private String popConfig;

    /**
     * 青海中行定制：任务列表id
     */
    private List<String> taskGuids;

    /**
    * 修改者id
    */
    private String modifiedId;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public List<String> getTaskGuids() {
        return taskGuids;
    }

    public void setTaskGuids(List<String> taskGuids) {
        this.taskGuids = taskGuids;
    }

    public Integer getStrategyObj() {
        return strategyObj;
    }

    public void setStrategyObj(Integer strategyObj) {
        this.strategyObj = strategyObj;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setStrategyName(String strategyName) {
        this.strategyName = strategyName;
    }

    public String getStrategyName() {
        return strategyName;
    }

    public void setStrategyType(String strategyType) {
        this.strategyType = strategyType;
    }

    public String getStrategyType() {
        return strategyType;
    }

    public void setConsumerLabelIds(String consumerLabelIds) {
        this.consumerLabelIds = consumerLabelIds;
    }

    public String getConsumerLabelIds() {
        return consumerLabelIds;
    }

    public void setStrategyContent(String strategyContent) {
        this.strategyContent = strategyContent;
    }

    public String getStrategyContent() {
        return strategyContent;
    }

    public void setStrategyStatus(String strategyStatus) {
        this.strategyStatus = strategyStatus;
    }

    public String getStrategyStatus() {
        return strategyStatus;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateId() {
        return createId;
    }

    public void setModifiedId(String modifiedId) {
        this.modifiedId = modifiedId;
    }

    public String getModifiedId() {
        return modifiedId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getPopConfig() {
        return popConfig;
    }

    public void setPopConfig(String popConfig) {
        this.popConfig = popConfig;
    }
}
